@@ -1496,7 +1496,8 @@ oddjob_pid_service(pid_t pid, int status, void *data)
 		oddjob_dbus_send_message_response_success(task->msg,
 							  WEXITSTATUS(status),
 							  task->stdout_buffer,
-							  task->stderr_buffer);
+							  task->stderr_buffer,
+							  FALSE);
 	}
 	/* Free the task. */
 	task->pid = -1;
@@ -2170,7 +2171,7 @@ oddjobd_list_methods(struct oddjob_dbus_context *ctx,
 			}
 		}
 	}
-	oddjob_dbus_send_message_response_text(msg, 0, result);
+	oddjob_dbus_send_message_response_text(msg, 0, result, FALSE);
 	oddjob_free(result);
 }
 
@@ -2463,7 +2464,7 @@ oddjobd_quit_method(struct oddjob_dbus_context *ctx,
 	if (globals.debug) {
 		fprintf(stderr, "Shutting down.\n");
 	}
-	oddjob_dbus_send_message_response_text(msg, 0, "");
+	oddjob_dbus_send_message_response_text(msg, 0, "", FALSE);
 	globals.quit++;
 }
 
@@ -2883,7 +2884,8 @@ oddjobd_reload_method(struct oddjob_dbus_context *ctx,
 	if (oddjobd_reload_configuration(ctx, &reason)) {
 		oddjob_dbus_send_message_response_text(msg,
 						       0,
-						       "Reload succeeded.");
+						       "Reload succeeded.",
+						       FALSE);
 	} else {
 		oddjob_dbus_send_message_response_error(msg,
 							ODDJOB_ERROR_INTERNAL,
